clear all  % you'll lose all variables in workspace!
close all  % all figures will be closed!

%%%% parameter definitions %%%%

num_1 = 5; % number of subjects in group 1
num_2 = 5; % number of subjects in group 2

duration_1 = 50; % duration of transient connectivity states in group 1
duration_2 = 50; % duration of transient connectivity states in group 2

num_state_1_1 = 4; % number of "state 1" connectivity state in group 1
num_state_1_2 = 4; % number of "state 1" connectivity state in group 2

num_state_2_1 = 4; % number of "state 2" connectivity state in group 1
num_state_2_2 = 4; % number of "state 2" connectivity state in group 2


noise_state_1_1 = [0.1, 0.1, 0.1]; % noise vector for state 1 in group 1
noise_state_1_2 = [0.1, 0.1, 0.1]; % noise vecotr for state 1 in group 2

noise_state_2_1 = [0.5, 0.1, 0.1]; % noise vector for state 2 in group 1
noise_state_2_2 = [0.1, 0.1, 0.1]; % noise vector for state 2 in group 2

window_length = 20; % window length for the sliding correlation analysis
num_clus = 2; % number of clusters for the separation into connectivity states

disp('Creating synthetic data...');

timeseries_1 = [];  % time series with the "ground truth" time series of states
timeseries_2 = [];

data_1 = [];
for i = 1:num_1
    [state_1, state_2, timeseries, data] = create_synth_data(num_state_1_1, num_state_2_1, duration_1, noise_state_1_1, noise_state_2_1);
    data_1(:,:,i) = data;
    timeseries_1 = vertcat(timeseries_1, timeseries');
end

data_2 = [];
for i = 1:num_2
    [state_1, state_2, timeseries, data] = create_synth_data(num_state_1_2, num_state_2_2, duration_2, noise_state_1_2, noise_state_2_2);
    data_2(:,:,i) = data;
    timeseries_2 = vertcat(timeseries_2, timeseries');
end

%%%% main analysis step %%%%

[mean_1, mean_2, p_val_mean, states_1, states_2, p_val, state_change_1, state_change_2, mean_var_1, mean_var_2, p_val_var] = dynamical_FC_analysis_main(data_1, data_2, window_length, num_clus);

%%%% outputs:
% mean_1 = mean connectivity over the whole session, group 1
% mean_2 = mean connectivity over the whole session, group 2
% p_val_mean = p values for 2nd level analysis over the whole session

% states_1 = average transient connectivity states, group 1
% states_2 = average transient connectivity states, group 2
% p_val = p values for 2nd level analysis for each state

% state_change_1 = time series of state changes for group 1
% state_change_2 = time series of state changes for group 2

% mean_var_1 = mean functional connectivity variance for group 1
% mean_var_2 = mean functional connectivity variance for group 2
% p_val_var = p values for 2nd level analysis, FC variance

%%%% visualization %%%%

% fig 1

figure;
subplot(2,1,1);
title('Timeseries of state changes (Group 1)')
xlabel('Time (volumes; all datasets concatenated')
ylabel('Change of state')
axis([1, length(timeseries_1),-0.5 1.5])
hold all;
plot(state_change_1, 'b');
plot(abs(diff(timeseries_1)), 'r');
legend('Estimated state changes','True state changes')


subplot(2,1,2);
title('Timeseries of state changes (Group 2)')
xlabel('Time (volumes; all datasets concatenated')
ylabel('Change of state')
axis([1, length(timeseries_2),-0.5 1.5])
hold all;
plot(state_change_2, 'b');
plot(abs(diff(timeseries_2)), 'r');
legend('Estimated state changes','True state changes')
fig=gcf;
set(findall(fig,'-property','FontSize'),'FontSize',12)

% fig 2

figure;
subplot(1,3,1);
pcolor(mean_1);
xlabel('Region of interest number')
ylabel('Region of interest number')
title('Average static functional connectivity (group 1)')
caxis([-1 1]);
colorbar;

subplot(1,3,2);
pcolor(mean_2);
xlabel('Region of interest number')
ylabel('Region of interest number')
title('Average static functional connectivity (group 2)')
caxis([-1 1]);
colorbar;

subplot(1,3,3);
pcolor(double(p_val_mean<0.001));
xlabel('Region of interest number')
ylabel('Region of interest number')
title('Significantly different connectivity (p<0.001)')
caxis([-1 1]);
fig=gcf;
set(findall(fig,'-property','FontSize'),'FontSize',12)


% fig 3

figure;
subplot(1,3,1);
pcolor(mean_var_1);
xlabel('Region of interest number')
ylabel('Region of interest number')
title('Functional connectivity variance (group 1)')
caxis([-0.005 0.005]);
colorbar;

subplot(1,3,2);
pcolor(mean_var_2);
xlabel('Region of interest number')
ylabel('Region of interest number')
title('Functional connectivity variance (group 2)')
caxis([-0.005 0.005]);
colorbar;

subplot(1,3,3);
pcolor(double(p_val_var<0.001));
xlabel('Region of interest number')
ylabel('Region of interest number')
title('Significantly different FC variance (p<0.001)')
caxis([-1 1]);
fig=gcf;
set(findall(fig,'-property','FontSize'),'FontSize',12)


% fig 4

figure;

n = 0;

for j = 1:num_clus
    n = n+1;
    subplot(3,num_clus,n);
    title_str = strcat('Average State ', num2str(j), ' (group 1)');
    pcolor(states_1(:,:,j));
    xlabel('Region of interest number')
    ylabel('Region of interest number')
    title(title_str)
    caxis([-1 1]);
    colorbar;
    shading flat
    
end


for j = 1:num_clus
    n = n+1;
    subplot(3,num_clus,n);
    title_str = strcat('Average State ', num2str(j), ' (group 2)');
    pcolor(states_2(:,:,j));
    xlabel('Region of interest number')
    ylabel('Region of interest number')
    title(title_str)
    caxis([-1 1]);
    colorbar;
    shading flat
    
end

for j = 1:num_clus
    n = n+1;
    subplot(3,num_clus,n);
    title_str = strcat('Significant differences ', num2str(j), ' (p<0.001)');
    pcolor(double(p_val(:,:,j) < 0.001));
    xlabel('Region of interest number')
    ylabel('Region of interest number')
    title(title_str)
    caxis([-1 1]);
    shading flat
    
end

fig=gcf;
set(findall(fig,'-property','FontSize'),'FontSize',12)



